@@ -114,13 +114,12 @@ NetworkModuleWidget::NetworkModuleWidget(QWidget *parent)
     m_modelpages->appendRow(aprxit);
     GSettingWatcher::instance()->bind("applicationProxy", m_lvnmpages, aprxit);
 
-    DStandardItem *infoit = new DStandardItem(tr("Network Details"));
-    infoit->setData(QVariant::fromValue(PageType::NetworkInfoPage), SectionRole);
-    infoit->setIcon(QIcon::fromTheme("dcc_network"));
-    m_modelpages->appendRow(infoit);
-    GSettingWatcher::instance()->bind("networkDetails", m_lvnmpages, infoit);
+    //~ contents_path /network/Airplane
+    DStandardItem *airplanemode = new DStandardItem(tr("Airplane Mode"));
+    airplanemode->setData(QVariant::fromValue(PageType::AirplaneModepage), SectionRole);
+    airplanemode->setIcon(QIcon::fromTheme("dcc_airplane_mode"));
+    m_modelpages->appendRow(airplanemode);
 
-    m_centralLayout->addWidget(m_lvnmpages);
     if (IsServerSystem)
         handleNMEditor();
 
@@ -145,6 +144,14 @@ NetworkModuleWidget::NetworkModuleWidget(QWidget *parent)
 
     initIpConflictInfo(pNetworkController->devices());
     onDeviceChanged();
+
+    DStandardItem *infoit = new DStandardItem(tr("Network Details"));
+    infoit->setData(QVariant::fromValue(PageType::NetworkInfoPage), SectionRole);
+    infoit->setIcon(QIcon::fromTheme("dcc_network"));
+    m_modelpages->appendRow(infoit);
+    GSettingWatcher::instance()->bind("networkDetails", m_lvnmpages, infoit);
+
+    m_centralLayout->addWidget(m_lvnmpages);
     QTimer::singleShot(0, this, [ proxyController, this ] {
         proxyController->querySysProxyData();
         onProxyMethodChanged(proxyController->proxyMethod());
@@ -207,6 +214,9 @@ void NetworkModuleWidget::selectListIndex(const QModelIndex &idx)
     case PageType::WirelessPage:
         Q_EMIT requestShowDeviceDetail(idx.data(DeviceRole).value<NetworkDeviceBase *>(), searchPath);
         break;
+    case PageType::AirplaneModepage:
+        Q_EMIT requestShowAirplanePage();
+        break;
     default:
         break;
     }
@@ -335,6 +345,9 @@ static PageType getPageTypeFromModelName(const QString &modelName)
     if (modelName == "networkVpn")
         return PageType::VPNPage;
 
+    if (modelName == "networkAirplane")
+        return PageType::AirplaneModepage;
+
     return PageType::NonePage;
 }
 
@@ -342,8 +355,9 @@ void NetworkModuleWidget::setModelVisible(const QString &modelName, const bool &
 {
     PageType type = getPageTypeFromModelName(modelName);
     for (int i = 0; i < m_modelpages->rowCount(); i++) {
-        if (m_modelpages->item(i)->data(SectionRole).value<PageType>() == type)
+        if (m_modelpages->item(i)->data(SectionRole).value<PageType>() == type) {
             m_lvnmpages->setRowHidden(i, !visible);
+        }
     }
 }
 
@@ -368,6 +382,8 @@ int NetworkModuleWidget::gotoSetting(const QString &path)
         type = PageType::WiredPage;
     } else if (path == QStringLiteral("Personal Hotspot")) {
         type = PageType::HotspotPage;
+    } else if (path == QStringLiteral("Airplane Mode")) {
+        type = PageType::AirplaneModepage;
     }
     int index = -1;
     for (int i = 0; i < m_modelpages->rowCount(); ++i) {
