@@ -71,7 +71,11 @@ SecretWirelessSection::SecretWirelessSection(WirelessSecuritySetting::Ptr wsSeti
             }
         }
     } else if (m_currentKeyMgmt == WirelessSecuritySetting::KeyMgmt::WpaPsk ||
-               m_currentKeyMgmt == NetworkManager::WirelessSecuritySetting::KeyMgmt::WpaSae) {
+#ifdef USE_DEEPIN_NMQT
+                m_currentKeyMgmt == NetworkManager::WirelessSecuritySetting::KeyMgmt::WpaSae) {
+#else
+                m_currentKeyMgmt == NetworkManager::WirelessSecuritySetting::KeyMgmt::SAE) {
+#endif
         NetworkManager::Setting::SecretFlags passwordFlags = m_wsSetting->pskFlags();
         QString strKey = m_wsSetting->psk();
         for (auto it = PasswordFlagsStrMap.cbegin(); it != PasswordFlagsStrMap.cend(); ++it) {
@@ -110,7 +114,11 @@ bool SecretWirelessSection::allInputValid()
     }
 
     if (m_currentKeyMgmt == WirelessSecuritySetting::KeyMgmt::WpaPsk ||
+#ifdef USE_DEEPIN_NMQT
             m_currentKeyMgmt == NetworkManager::WirelessSecuritySetting::KeyMgmt::WpaSae) {
+#else
+            m_currentKeyMgmt == NetworkManager::WirelessSecuritySetting::KeyMgmt::SAE) {
+#endif
         if (m_currentPasswordType != Setting::NotSaved) {
             valid = wpaPskIsValid(m_passwdEdit->text());
             m_passwdEdit->setIsErr(!valid);
@@ -142,7 +150,11 @@ void SecretWirelessSection::saveSettings()
         m_wsSetting->setPskFlags(Setting::NotRequired);
         m_wsSetting->setAuthAlg(m_currentAuthAlg);
     } else if (m_currentKeyMgmt == WirelessSecuritySetting::KeyMgmt::WpaPsk ||
-               m_currentKeyMgmt == NetworkManager::WirelessSecuritySetting::KeyMgmt::WpaSae) {
+#ifdef USE_DEEPIN_NMQT
+                    m_currentKeyMgmt == NetworkManager::WirelessSecuritySetting::KeyMgmt::WpaSae) {
+#else
+                    m_currentKeyMgmt == NetworkManager::WirelessSecuritySetting::KeyMgmt::SAE) {
+#endif
         m_wsSetting->setPskFlags(m_currentPasswordType);
         if (m_currentPasswordType != Setting::NotSaved)
             m_wsSetting->setPsk(m_passwdEdit->text());
@@ -167,7 +179,11 @@ void SecretWirelessSection::initStrMaps()
         { tr("WEP"), WirelessSecuritySetting::KeyMgmt::Wep },
         { tr("WPA/WPA2 Personal"), WirelessSecuritySetting::KeyMgmt::WpaPsk },
         { tr("WPA/WPA2 Enterprise"), WirelessSecuritySetting::KeyMgmt::WpaEap },
+#ifdef USE_DEEPIN_NMQT
         { tr("WPA3 Personal"), NetworkManager::WirelessSecuritySetting::KeyMgmt::WpaSae }
+#else
+        { tr("WPA3 Personal"), NetworkManager::WirelessSecuritySetting::KeyMgmt::SAE }
+#endif
     };
 
     AuthAlgStrMap = {
@@ -258,7 +274,11 @@ void SecretWirelessSection::initConnection()
             break;
         }
         case WirelessSecuritySetting::KeyMgmt::WpaPsk:
-        case WirelessSecuritySetting::KeyMgmt::WpaSae:{
+#ifdef USE_DEEPIN_NMQT
+        case WirelessSecuritySetting::KeyMgmt::WpaSae: {
+#else
+        case WirelessSecuritySetting::KeyMgmt::SAE: {
+#endif
             m_passwdEdit->setText(m_wsSetting->psk());
             m_passwdEdit->setTitle(tr("Password"));
             m_passwdEdit->setVisible(enabled);
@@ -318,7 +338,11 @@ void SecretWirelessSection::onKeyMgmtChanged(WirelessSecuritySetting::KeyMgmt ke
         m_authAlgChooser->setVisible(false);
         break;
     }
+#ifdef USE_DEEPIN_NMQT
     case WirelessSecuritySetting::KeyMgmt::WpaSae: {
+#else
+    case WirelessSecuritySetting::KeyMgmt::SAE: {
+#endif
         if (m_currentPasswordType != NetworkManager::Setting::NotSaved) {
             m_passwdEdit->setText(m_wsSetting->psk());
             m_passwdEdit->setTitle(tr("Password"));
@@ -342,4 +366,4 @@ void SecretWirelessSection::onKeyMgmtChanged(WirelessSecuritySetting::KeyMgmt ke
 void SecretWirelessSection::saveUserInputPassword()
 {
     m_userInputPasswordMap.insert(m_currentKeyMgmt, m_passwdEdit->text());
-}
\ No newline at end of file
+}
