@@ -78,6 +78,14 @@
         <comment>button</comment>
         <translation>Saxla</translation>
     </message>
+    <message>
+        <source>Connecting</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Disconnect</source>
+        <translation>Bağlantını ləğv et</translation>
+    </message>
     <message>
         <source>Are you sure you want to delete this configuration?</source>
         <translation>Bu tənzimləmənisilmək istədiyinizə əminsiniz?</translation>
@@ -197,6 +205,12 @@
         <source>VPN</source>
         <translation>VPN</translation>
     </message>
+    <message>
+        <source>Airplane Mode</source>
+        <translation>Təyyarə rejimi</translation>
+        <extra-child_page>Airplane Mode</extra-child_page>
+        <extra-contents_path>/network/Airplane Mode</extra-contents_path>
+    </message>
     <message>
         <source>Wired Network Adapter</source>
         <translation>Naqilli şəbəkə uzlaşdırıcısı</translation>
@@ -358,6 +372,17 @@
         <extra-contents_path>/network/Network Details</extra-contents_path>
     </message>
 </context>
+<context>
+    <name>dccV20::network::AirplaneModepage</name>
+    <message>
+        <source>Airplane Mode</source>
+        <translation>Təyyarə rejimi</translation>
+    </message>
+    <message>
+        <source>Enabling the airplane mode turns off wireless network, personal hotspot and Bluetooth</source>
+        <translation>Təyyarə rejiminin işə salınması simsiz şəbəkəni, fərdi qoşulma nötəsini və Bluetooth-u söndürür</translation>
+    </message>
+</context>
 <context>
     <name>DNSSection</name>
     <message>
@@ -644,6 +669,11 @@
         <source>Application Proxy</source>
         <translation>Tətbiq proksisi</translation>
     </message>
+    <message>
+        <source>Airplane Mode</source>
+        <translation>Təyyarə rejimi</translation>
+        <extra-contents_path>/network/Airplane</extra-contents_path>
+    </message>
     <message>
         <source>Network Details</source>
         <translation>Şəbəkə məlumatları</translation>
@@ -1922,14 +1952,14 @@
         <source>Security Type</source>
         <translation>Təhlükəsizlik növü</translation>
     </message>
-    <message>
-        <source>Band</source>
-        <translation>Aralıq</translation>
-    </message>
     <message>
         <source>Channel</source>
         <translation>Kanal</translation>
     </message>
+    <message>
+        <source>Band</source>
+        <translation>Aralıq</translation>
+    </message>
     <message>
         <source>Interface</source>
         <translation>İnterfeys</translation>
