@@ -78,6 +78,14 @@
         <comment>button</comment>
         <translation>ཉར་ཚགས། </translation>
     </message>
+    <message>
+        <source>Connecting</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Disconnect</source>
+        <translation>སྦྲེལ་མཐུད་ཕྲལ་གཅོད། </translation>
+    </message>
     <message>
         <source>Are you sure you want to delete this configuration?</source>
         <translation>ཁྱོད་ཀྱིས་མིག་སྔའི་སྡེབ་སྒྲིག་བསུབ་རྒྱུ་ཡིན་པ་གཏན་ཁེལ་ལམ།</translation>
@@ -197,6 +205,12 @@
         <source>VPN</source>
         <translation>VPN</translation>
     </message>
+    <message>
+        <source>Airplane Mode</source>
+        <translation>འཕུར་སྐྱོད་དཔེ་རྣམ།</translation>
+        <extra-child_page>Airplane Mode</extra-child_page>
+        <extra-contents_path>/network/Airplane Mode</extra-contents_path>
+    </message>
     <message>
         <source>Wired Network Adapter</source>
         <translation>སྐུད་ཡོད་དྲ་ཁཱ།</translation>
@@ -358,6 +372,17 @@
         <extra-contents_path>/network/Network Details</extra-contents_path>
     </message>
 </context>
+<context>
+    <name>dccV20::network::AirplaneModepage</name>
+    <message>
+        <source>Airplane Mode</source>
+        <translation>འཕུར་སྐྱོད་དཔེ་རྣམ།</translation>
+    </message>
+    <message>
+        <source>Enabling the airplane mode turns off wireless network, personal hotspot and Bluetooth</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
 <context>
     <name>DNSSection</name>
     <message>
@@ -644,6 +669,11 @@
         <source>Application Proxy</source>
         <translation>ཉེར་སྤྱོད་ལས་ཚབ།</translation>
     </message>
+    <message>
+        <source>Airplane Mode</source>
+        <translation>འཕུར་སྐྱོད་དཔེ་རྣམ།</translation>
+        <extra-contents_path>/network/Airplane</extra-contents_path>
+    </message>
     <message>
         <source>Network Details</source>
         <translation>དྲ་རྒྱ་ཞིབ་ཕྲ།</translation>
@@ -1922,14 +1952,14 @@
         <source>Security Type</source>
         <translation>བདེ་འཇགས་རིགས།</translation>
     </message>
-    <message>
-        <source>Band</source>
-        <translation>བྱུང་རིམ།</translation>
-    </message>
     <message>
         <source>Channel</source>
         <translation>དྲ་རྒྱའི་རྒྱུ་ལམ།</translation>
     </message>
+    <message>
+        <source>Band</source>
+        <translation>བྱུང་རིམ།</translation>
+    </message>
     <message>
         <source>Interface</source>
         <translation>མཐུད་ཁ།</translation>
