@@ -78,6 +78,14 @@
         <comment>button</comment>
         <translation>Desa</translation>
     </message>
+    <message>
+        <source>Connecting</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Disconnect</source>
+        <translation>Desconnecta</translation>
+    </message>
     <message>
         <source>Are you sure you want to delete this configuration?</source>
         <translation>Segur que voleu eliminar aquesta configuració?</translation>
@@ -197,6 +205,12 @@
         <source>VPN</source>
         <translation>XPV</translation>
     </message>
+    <message>
+        <source>Airplane Mode</source>
+        <translation>Mode d&apos;avió</translation>
+        <extra-child_page>Airplane Mode</extra-child_page>
+        <extra-contents_path>/network/Airplane Mode</extra-contents_path>
+    </message>
     <message>
         <source>Wired Network Adapter</source>
         <translation>Adaptador de la xarxa amb fil</translation>
@@ -358,6 +372,17 @@
         <extra-contents_path>/network/Network Details</extra-contents_path>
     </message>
 </context>
+<context>
+    <name>dccV20::network::AirplaneModepage</name>
+    <message>
+        <source>Airplane Mode</source>
+        <translation>Mode d&apos;avió</translation>
+    </message>
+    <message>
+        <source>Enabling the airplane mode turns off wireless network, personal hotspot and Bluetooth</source>
+        <translation>Habilitar el mode d&apos;avió inhabilita la xarxa sense fil, el punt d&apos;accés personal i el Bluetooth.</translation>
+    </message>
+</context>
 <context>
     <name>DNSSection</name>
     <message>
@@ -460,7 +485,7 @@
     </message>
     <message>
         <source>Required</source>
-        <translation>Necessari</translation>
+        <translation>Cal</translation>
     </message>
     <message>
         <source>Gateway</source>
@@ -495,7 +520,7 @@
     </message>
     <message>
         <source>Required</source>
-        <translation>Necessari</translation>
+        <translation>Cal</translation>
     </message>
 </context>
 <context>
@@ -644,6 +669,11 @@
         <source>Application Proxy</source>
         <translation>Aplicació de servidor intermediari</translation>
     </message>
+    <message>
+        <source>Airplane Mode</source>
+        <translation>Mode d&apos;avió</translation>
+        <extra-contents_path>/network/Airplane</extra-contents_path>
+    </message>
     <message>
         <source>Network Details</source>
         <translation>Detalls de la xarxa</translation>
@@ -1922,14 +1952,14 @@
         <source>Security Type</source>
         <translation>Tipus de seguretat</translation>
     </message>
-    <message>
-        <source>Band</source>
-        <translation>Banda</translation>
-    </message>
     <message>
         <source>Channel</source>
         <translation>Canal</translation>
     </message>
+    <message>
+        <source>Band</source>
+        <translation>Banda</translation>
+    </message>
     <message>
         <source>Interface</source>
         <translation>Interfície</translation>
