@@ -78,6 +78,14 @@
         <comment>button</comment>
         <translation>Speichern</translation>
     </message>
+    <message>
+        <source>Connecting</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Disconnect</source>
+        <translation>Trennen</translation>
+    </message>
     <message>
         <source>Are you sure you want to delete this configuration?</source>
         <translation>Sind Sie sicher, dass Sie diese Konfiguration löschen möchten?</translation>
@@ -197,6 +205,12 @@
         <source>VPN</source>
         <translation>VPN</translation>
     </message>
+    <message>
+        <source>Airplane Mode</source>
+        <translation>Flugzeugmodus</translation>
+        <extra-child_page>Airplane Mode</extra-child_page>
+        <extra-contents_path>/network/Airplane Mode</extra-contents_path>
+    </message>
     <message>
         <source>Wired Network Adapter</source>
         <translation>Kabelgebundener Netzwerkadapter</translation>
@@ -358,6 +372,17 @@
         <extra-contents_path>/network/Network Details</extra-contents_path>
     </message>
 </context>
+<context>
+    <name>dccV20::network::AirplaneModepage</name>
+    <message>
+        <source>Airplane Mode</source>
+        <translation>Flugzeugmodus</translation>
+    </message>
+    <message>
+        <source>Enabling the airplane mode turns off wireless network, personal hotspot and Bluetooth</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
 <context>
     <name>DNSSection</name>
     <message>
@@ -644,6 +669,11 @@
         <source>Application Proxy</source>
         <translation>Anwendungsproxy</translation>
     </message>
+    <message>
+        <source>Airplane Mode</source>
+        <translation>Flugzeugmodus</translation>
+        <extra-contents_path>/network/Airplane</extra-contents_path>
+    </message>
     <message>
         <source>Network Details</source>
         <translation>Netzwerkdetails</translation>
@@ -1922,14 +1952,14 @@
         <source>Security Type</source>
         <translation>Sicherheitstyp</translation>
     </message>
-    <message>
-        <source>Band</source>
-        <translation>Band</translation>
-    </message>
     <message>
         <source>Channel</source>
         <translation>Kanal</translation>
     </message>
+    <message>
+        <source>Band</source>
+        <translation>Band</translation>
+    </message>
     <message>
         <source>Interface</source>
         <translation>Schnittstelle</translation>
