@@ -78,6 +78,14 @@
         <comment>button</comment>
         <translation>Guardar</translation>
     </message>
+    <message>
+        <source>Connecting</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Disconnect</source>
+        <translation>Desconectar</translation>
+    </message>
     <message>
         <source>Are you sure you want to delete this configuration?</source>
         <translation>¿Está seguro que desea borrar la configuración?</translation>
@@ -197,6 +205,12 @@
         <source>VPN</source>
         <translation>VPN</translation>
     </message>
+    <message>
+        <source>Airplane Mode</source>
+        <translation>Modo avión</translation>
+        <extra-child_page>Airplane Mode</extra-child_page>
+        <extra-contents_path>/network/Airplane Mode</extra-contents_path>
+    </message>
     <message>
         <source>Wired Network Adapter</source>
         <translation>Tarjeta de red cableada</translation>
@@ -358,6 +372,17 @@
         <extra-contents_path>/network/Network Details</extra-contents_path>
     </message>
 </context>
+<context>
+    <name>dccV20::network::AirplaneModepage</name>
+    <message>
+        <source>Airplane Mode</source>
+        <translation>Modo avión</translation>
+    </message>
+    <message>
+        <source>Enabling the airplane mode turns off wireless network, personal hotspot and Bluetooth</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
 <context>
     <name>DNSSection</name>
     <message>
@@ -644,6 +669,11 @@
         <source>Application Proxy</source>
         <translation>Proxy de aplicación</translation>
     </message>
+    <message>
+        <source>Airplane Mode</source>
+        <translation>Modo avión</translation>
+        <extra-contents_path>/network/Airplane</extra-contents_path>
+    </message>
     <message>
         <source>Network Details</source>
         <translation>Detalles de red</translation>
@@ -1922,14 +1952,14 @@
         <source>Security Type</source>
         <translation>Tipo de Seguridad</translation>
     </message>
-    <message>
-        <source>Band</source>
-        <translation>Banda</translation>
-    </message>
     <message>
         <source>Channel</source>
         <translation>Canal</translation>
     </message>
+    <message>
+        <source>Band</source>
+        <translation>Banda</translation>
+    </message>
     <message>
         <source>Interface</source>
         <translation>Interfaz</translation>
@@ -2030,7 +2060,7 @@
     </message>
     <message>
         <source>Wireless Network</source>
-        <translation>Red cableada</translation>
+        <translation>Red inalámbrica</translation>
     </message>
     <message>
         <source>Wireless Network %1</source>
