@@ -78,6 +78,14 @@
         <comment>button</comment>
         <translation>Mentés</translation>
     </message>
+    <message>
+        <source>Connecting</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Disconnect</source>
+        <translation>Szétkapcsolás</translation>
+    </message>
     <message>
         <source>Are you sure you want to delete this configuration?</source>
         <translation>Biztosan törölni szeretné ezt a beállítást?</translation>
@@ -197,6 +205,12 @@
         <source>VPN</source>
         <translation>VPN</translation>
     </message>
+    <message>
+        <source>Airplane Mode</source>
+        <translation>Repülőgép üzemmód</translation>
+        <extra-child_page>Airplane Mode</extra-child_page>
+        <extra-contents_path>/network/Airplane Mode</extra-contents_path>
+    </message>
     <message>
         <source>Wired Network Adapter</source>
         <translation>Vezetékes hálózati kártya</translation>
@@ -358,6 +372,17 @@
         <extra-contents_path>/network/Network Details</extra-contents_path>
     </message>
 </context>
+<context>
+    <name>dccV20::network::AirplaneModepage</name>
+    <message>
+        <source>Airplane Mode</source>
+        <translation>Repülőgép üzemmód</translation>
+    </message>
+    <message>
+        <source>Enabling the airplane mode turns off wireless network, personal hotspot and Bluetooth</source>
+        <translation>A repülőgép üzemmód engedélyezése kikapcsolja a vezeték nélküli hálózatot, a személyes hotspotot és a Bluetooth-t</translation>
+    </message>
+</context>
 <context>
     <name>DNSSection</name>
     <message>
@@ -644,6 +669,11 @@
         <source>Application Proxy</source>
         <translation>Alkalmazás proxy</translation>
     </message>
+    <message>
+        <source>Airplane Mode</source>
+        <translation>Repülőgép üzemmód</translation>
+        <extra-contents_path>/network/Airplane</extra-contents_path>
+    </message>
     <message>
         <source>Network Details</source>
         <translation>Hálózati adatok</translation>
@@ -1922,14 +1952,14 @@
         <source>Security Type</source>
         <translation>Biztonság típusa</translation>
     </message>
-    <message>
-        <source>Band</source>
-        <translation>Sáv</translation>
-    </message>
     <message>
         <source>Channel</source>
         <translation>Csatorna</translation>
     </message>
+    <message>
+        <source>Band</source>
+        <translation>Sáv</translation>
+    </message>
     <message>
         <source>Interface</source>
         <translation>Felület</translation>
