@@ -78,6 +78,14 @@
         <comment>button</comment>
         <translation>저장</translation>
     </message>
+    <message>
+        <source>Connecting</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Disconnect</source>
+        <translation>연결 해제</translation>
+    </message>
     <message>
         <source>Are you sure you want to delete this configuration?</source>
         <translation>이 환경설정을 삭제하시겠습니까?</translation>
@@ -197,6 +205,12 @@
         <source>VPN</source>
         <translation>VPN</translation>
     </message>
+    <message>
+        <source>Airplane Mode</source>
+        <translation>비행기 모드</translation>
+        <extra-child_page>Airplane Mode</extra-child_page>
+        <extra-contents_path>/network/Airplane Mode</extra-contents_path>
+    </message>
     <message>
         <source>Wired Network Adapter</source>
         <translation>유선 네트워크 어댑터</translation>
@@ -358,6 +372,17 @@
         <extra-contents_path>/network/Network Details</extra-contents_path>
     </message>
 </context>
+<context>
+    <name>dccV20::network::AirplaneModepage</name>
+    <message>
+        <source>Airplane Mode</source>
+        <translation>비행기 모드</translation>
+    </message>
+    <message>
+        <source>Enabling the airplane mode turns off wireless network, personal hotspot and Bluetooth</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
 <context>
     <name>DNSSection</name>
     <message>
@@ -644,6 +669,11 @@
         <source>Application Proxy</source>
         <translation>응용프로그램 프록시</translation>
     </message>
+    <message>
+        <source>Airplane Mode</source>
+        <translation>비행기 모드</translation>
+        <extra-contents_path>/network/Airplane</extra-contents_path>
+    </message>
     <message>
         <source>Network Details</source>
         <translation>네트워크 세부정보</translation>
@@ -1922,14 +1952,14 @@
         <source>Security Type</source>
         <translation>보안 유형</translation>
     </message>
-    <message>
-        <source>Band</source>
-        <translation>밴드</translation>
-    </message>
     <message>
         <source>Channel</source>
         <translation>채널</translation>
     </message>
+    <message>
+        <source>Band</source>
+        <translation>밴드</translation>
+    </message>
     <message>
         <source>Interface</source>
         <translation>인터페이스</translation>
