@@ -78,6 +78,14 @@
         <comment>button</comment>
         <translation>Opslaan</translation>
     </message>
+    <message>
+        <source>Connecting</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Disconnect</source>
+        <translation>Verbinding verbreken</translation>
+    </message>
     <message>
         <source>Are you sure you want to delete this configuration?</source>
         <translation>Weet je zeker dat je deze configuratie wilt verwijderen?</translation>
@@ -197,6 +205,12 @@
         <source>VPN</source>
         <translation>VPN</translation>
     </message>
+    <message>
+        <source>Airplane Mode</source>
+        <translation>Vliegtuigstand</translation>
+        <extra-child_page>Airplane Mode</extra-child_page>
+        <extra-contents_path>/network/Airplane Mode</extra-contents_path>
+    </message>
     <message>
         <source>Wired Network Adapter</source>
         <translation>Bekabelde netwerkadapter</translation>
@@ -358,6 +372,17 @@
         <extra-contents_path>/network/Network Details</extra-contents_path>
     </message>
 </context>
+<context>
+    <name>dccV20::network::AirplaneModepage</name>
+    <message>
+        <source>Airplane Mode</source>
+        <translation>Vliegtuigstand</translation>
+    </message>
+    <message>
+        <source>Enabling the airplane mode turns off wireless network, personal hotspot and Bluetooth</source>
+        <translation>Door de vliegtuigstand worden draadloos internet, bluetooth en uw persoonlijke hotspot uitgeschakeld</translation>
+    </message>
+</context>
 <context>
     <name>DNSSection</name>
     <message>
@@ -644,6 +669,11 @@
         <source>Application Proxy</source>
         <translation>Programmaproxy</translation>
     </message>
+    <message>
+        <source>Airplane Mode</source>
+        <translation>Vliegtuigstand</translation>
+        <extra-contents_path>/network/Airplane</extra-contents_path>
+    </message>
     <message>
         <source>Network Details</source>
         <translation>Netwerkinformatie</translation>
@@ -1922,14 +1952,14 @@
         <source>Security Type</source>
         <translation>Soort beveiliging</translation>
     </message>
-    <message>
-        <source>Band</source>
-        <translation>Band</translation>
-    </message>
     <message>
         <source>Channel</source>
         <translation>Kanaal</translation>
     </message>
+    <message>
+        <source>Band</source>
+        <translation>Band</translation>
+    </message>
     <message>
         <source>Interface</source>
         <translation>Interface</translation>
