@@ -78,6 +78,14 @@
         <comment>button</comment>
         <translation>Зберегти</translation>
     </message>
+    <message>
+        <source>Connecting</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Disconnect</source>
+        <translation>Відʼєднатися</translation>
+    </message>
     <message>
         <source>Are you sure you want to delete this configuration?</source>
         <translation>Ви впевнені, що хочете видалити цю конфігурацію?</translation>
@@ -197,6 +205,12 @@
         <source>VPN</source>
         <translation>VPN</translation>
     </message>
+    <message>
+        <source>Airplane Mode</source>
+        <translation>Режим польоту</translation>
+        <extra-child_page>Airplane Mode</extra-child_page>
+        <extra-contents_path>/network/Airplane Mode</extra-contents_path>
+    </message>
     <message>
         <source>Wired Network Adapter</source>
         <translation>Дротова Мережева Карта</translation>
@@ -358,6 +372,17 @@
         <extra-contents_path>/network/Network Details</extra-contents_path>
     </message>
 </context>
+<context>
+    <name>dccV20::network::AirplaneModepage</name>
+    <message>
+        <source>Airplane Mode</source>
+        <translation>Режим польоту</translation>
+    </message>
+    <message>
+        <source>Enabling the airplane mode turns off wireless network, personal hotspot and Bluetooth</source>
+        <translation>Вмикання режиму польоту вимикає бездротову мережу, особистку точку доступу та Bluetooth</translation>
+    </message>
+</context>
 <context>
     <name>DNSSection</name>
     <message>
@@ -644,6 +669,11 @@
         <source>Application Proxy</source>
         <translation>Проксі програми</translation>
     </message>
+    <message>
+        <source>Airplane Mode</source>
+        <translation>Режим польоту</translation>
+        <extra-contents_path>/network/Airplane</extra-contents_path>
+    </message>
     <message>
         <source>Network Details</source>
         <translation>Параметри мережі</translation>
@@ -1922,14 +1952,14 @@
         <source>Security Type</source>
         <translation>Тип захисту</translation>
     </message>
-    <message>
-        <source>Band</source>
-        <translation>Група</translation>
-    </message>
     <message>
         <source>Channel</source>
         <translation>Канал</translation>
     </message>
+    <message>
+        <source>Band</source>
+        <translation>Група</translation>
+    </message>
     <message>
         <source>Interface</source>
         <translation>Інтерфейс</translation>
